# HiC1Dmetrics
This repository contain code and basic tutorial for "HiC1Dmetrics"

![figure1](https://github.com/wangjk321/HiC1Dmetrics/blob/master/IMG/Figure1.png)

# Installation

HiC1Dmetrics was based on `python3` and released on [PyPI](https://pypi.org/project/h1d/), it could be installed by

```python
pip install h1d
```
After installation, try:
```
$ h1d -V
h1d version 0.1.0
```

# Documents

For detailed usage, please refer to [h1d Documents](https://h1d.readthedocs.io/en/latest/)

# Web application

Please click [hic1d webapp](http://hic1d.herokuapp.com)
